==> komga_api_client-0.41.1.tar.gz: doc/SeriesControllerApi.md <==
# komga_api_client.api.SeriesControllerApi

## Load the API package
```dart
import 'package:komga_api_client/api.dart';
```

All URIs are relative to *http://localhost:8080*

Method | HTTP request | Description
------------- | ------------- | -------------
[**analyze2**](SeriesControllerApi.md#analyze2) | **post** /api/v1/series/{seriesId}/analyze | 
[**getAllBooksBySeries**](SeriesControllerApi.md#getAllBooksBySeries) | **get** /api/v1/series/{seriesId}/books | 
[**getAllCollectionsBySeries**](SeriesControllerApi.md#getAllCollectionsBySeries) | **get** /api/v1/series/{seriesId}/collections | 
[**getAllSeries**](SeriesControllerApi.md#getAllSeries) | **get** /api/v1/series | 
[**getLatestSeries**](SeriesControllerApi.md#getLatestSeries) | **get** /api/v1/series/latest | 
[**getNewSeries**](SeriesControllerApi.md#getNewSeries) | **get** /api/v1/series/new | 
[**getOneSeries**](SeriesControllerApi.md#getOneSeries) | **get** /api/v1/series/{seriesId} | 
[**getSeriesThumbnail**](SeriesControllerApi.md#getSeriesThumbnail) | **get** /api/v1/series/{seriesId}/thumbnail | 
[**getUpdatedSeries**](SeriesControllerApi.md#getUpdatedSeries) | **get** /api/v1/series/updated | 
[**markAsRead**](SeriesControllerApi.md#markAsRead) | **post** /api/v1/series/{seriesId}/read-progress | 
[**markAsUnread**](SeriesControllerApi.md#markAsUnread) | **delete** /api/v1/series/{seriesId}/read-progress | 
[**refreshMetadata2**](SeriesControllerApi.md#refreshMetadata2) | **post** /api/v1/series/{seriesId}/metadata/refresh | 
[**updateMetadata1**](SeriesControllerApi.md#updateMetadata1) | **patch** /api/v1/series/{seriesId}/metadata | 


# **analyze2**
> analyze2(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.analyze2(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->analyze2: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAllBooksBySeries**
> PageBookDto getAllBooksBySeries(seriesId, mediaStatus, readStatus, page, size, sort)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 
var mediaStatus = []; // List<String> | 
var readStatus = []; // List<String> | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned
var sort = []; // List<String> | Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported.

try { 
    var result = api_instance.getAllBooksBySeries(seriesId, mediaStatus, readStatus, page, size, sort);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getAllBooksBySeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]
 **mediaStatus** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **readStatus** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]
 **sort** | [**List&lt;String&gt;**](String.md)| Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported. | [optional] [default to const []]

### Return type

[**PageBookDto**](PageBookDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAllCollectionsBySeries**
> List<CollectionDto> getAllCollectionsBySeries(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    var result = api_instance.getAllCollectionsBySeries(seriesId);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getAllCollectionsBySeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

[**List<CollectionDto>**](CollectionDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAllSeries**
> PageSeriesDto getAllSeries(search, libraryId, collectionId, status, readStatus, unpaged, page, size, sort)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var search = search_example; // String | 
var libraryId = []; // List<int> | 
var collectionId = []; // List<int> | 
var status = []; // List<String> | 
var readStatus = []; // List<String> | 
var unpaged = true; // bool | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned
var sort = []; // List<String> | Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported.

try { 
    var result = api_instance.getAllSeries(search, libraryId, collectionId, status, readStatus, unpaged, page, size, sort);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getAllSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**|  | [optional] [default to null]
 **libraryId** | [**List&lt;int&gt;**](int.md)|  | [optional] [default to const []]
 **collectionId** | [**List&lt;int&gt;**](int.md)|  | [optional] [default to const []]
 **status** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **readStatus** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **unpaged** | **bool**|  | [optional] [default to null]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]
 **sort** | [**List&lt;String&gt;**](String.md)| Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported. | [optional] [default to const []]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getLatestSeries**
> PageSeriesDto getLatestSeries(unpaged, page, size)



Return recently added or updated series.

### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var unpaged = true; // bool | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned

try { 
    var result = api_instance.getLatestSeries(unpaged, page, size);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getLatestSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **unpaged** | **bool**|  | [optional] [default to null]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getNewSeries**
> PageSeriesDto getNewSeries(unpaged, page, size)



Return newly added series.

### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var unpaged = true; // bool | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned

try { 
    var result = api_instance.getNewSeries(unpaged, page, size);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getNewSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **unpaged** | **bool**|  | [optional] [default to null]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOneSeries**
> SeriesDto getOneSeries(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    var result = api_instance.getOneSeries(seriesId);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getOneSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

[**SeriesDto**](SeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getSeriesThumbnail**
> Uint8List getSeriesThumbnail(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    var result = api_instance.getSeriesThumbnail(seriesId);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getSeriesThumbnail: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

[**Uint8List**](Uint8List.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: image/jpeg

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getUpdatedSeries**
> PageSeriesDto getUpdatedSeries(unpaged, page, size)



Return recently updated series, but not newly added ones.

### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var unpaged = true; // bool | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned

try { 
    var result = api_instance.getUpdatedSeries(unpaged, page, size);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getUpdatedSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **unpaged** | **bool**|  | [optional] [default to null]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **markAsRead**
> markAsRead(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.markAsRead(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->markAsRead: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **markAsUnread**
> markAsUnread(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.markAsUnread(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->markAsUnread: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refreshMetadata2**
> refreshMetadata2(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.refreshMetadata2(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->refreshMetadata2: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateMetadata1**
> SeriesDto updateMetadata1(seriesId, seriesMetadataUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 
var seriesMetadataUpdateDto = new SeriesMetadataUpdateDto(); // SeriesMetadataUpdateDto | Metadata fields to update. Set a field to null to unset the metadata. You can omit fields you don't want to update.

try { 
    var result = api_instance.updateMetadata1(seriesId, seriesMetadataUpdateDto);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->updateMetadata1: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]
 **seriesMetadataUpdateDto** | [**SeriesMetadataUpdateDto**](SeriesMetadataUpdateDto.md)| Metadata fields to update. Set a field to null to unset the metadata. You can omit fields you don&#39;t want to update. | 

### Return type

[**SeriesDto**](SeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> komga_api_client-37.0.0.tar.gz: doc/SeriesControllerApi.md <==
# komga_api_client.api.SeriesControllerApi

## Load the API package
```dart
import 'package:komga_api_client/api.dart';
```

All URIs are relative to *https://demo.komga.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**analyze2**](SeriesControllerApi.md#analyze2) | **post** /api/v1/series/{seriesId}/analyze | 
[**getAllBooksBySeries**](SeriesControllerApi.md#getAllBooksBySeries) | **get** /api/v1/series/{seriesId}/books | 
[**getAllSeries**](SeriesControllerApi.md#getAllSeries) | **get** /api/v1/series | 
[**getLatestSeries**](SeriesControllerApi.md#getLatestSeries) | **get** /api/v1/series/latest | 
[**getNewSeries**](SeriesControllerApi.md#getNewSeries) | **get** /api/v1/series/new | 
[**getOneSeries**](SeriesControllerApi.md#getOneSeries) | **get** /api/v1/series/{seriesId} | 
[**getSeriesThumbnail**](SeriesControllerApi.md#getSeriesThumbnail) | **get** /api/v1/series/{seriesId}/thumbnail | 
[**getUpdatedSeries**](SeriesControllerApi.md#getUpdatedSeries) | **get** /api/v1/series/updated | 
[**markAsRead**](SeriesControllerApi.md#markAsRead) | **post** /api/v1/series/{seriesId}/read-progress | 
[**markAsUnread**](SeriesControllerApi.md#markAsUnread) | **delete** /api/v1/series/{seriesId}/read-progress | 
[**refreshMetadata2**](SeriesControllerApi.md#refreshMetadata2) | **post** /api/v1/series/{seriesId}/metadata/refresh | 
[**updateMetadata1**](SeriesControllerApi.md#updateMetadata1) | **patch** /api/v1/series/{seriesId}/metadata | 


# **analyze2**
> analyze2(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.analyze2(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->analyze2: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAllBooksBySeries**
> PageBookDto getAllBooksBySeries(seriesId, mediaStatus, readStatus, page, size, sort)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 
var mediaStatus = []; // List<String> | 
var readStatus = []; // List<String> | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned
var sort = []; // List<String> | Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported.

try { 
    var result = api_instance.getAllBooksBySeries(seriesId, mediaStatus, readStatus, page, size, sort);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getAllBooksBySeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]
 **mediaStatus** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **readStatus** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]
 **sort** | [**List&lt;String&gt;**](String.md)| Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported. | [optional] [default to const []]

### Return type

[**PageBookDto**](PageBookDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAllSeries**
> PageSeriesDto getAllSeries(search, libraryId, status, readStatus, page, size, sort)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var search = search_example; // String | 
var libraryId = []; // List<int> | 
var status = []; // List<String> | 
var readStatus = []; // List<String> | 
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned
var sort = []; // List<String> | Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported.

try { 
    var result = api_instance.getAllSeries(search, libraryId, status, readStatus, page, size, sort);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getAllSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**|  | [optional] [default to null]
 **libraryId** | [**List&lt;int&gt;**](int.md)|  | [optional] [default to const []]
 **status** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **readStatus** | [**List&lt;String&gt;**](String.md)|  | [optional] [default to const []]
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]
 **sort** | [**List&lt;String&gt;**](String.md)| Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported. | [optional] [default to const []]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getLatestSeries**
> PageSeriesDto getLatestSeries(page, size)



Return recently added or updated series.

### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned

try { 
    var result = api_instance.getLatestSeries(page, size);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getLatestSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getNewSeries**
> PageSeriesDto getNewSeries(page, size)



Return newly added series.

### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned

try { 
    var result = api_instance.getNewSeries(page, size);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getNewSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOneSeries**
> SeriesDto getOneSeries(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    var result = api_instance.getOneSeries(seriesId);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getOneSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

[**SeriesDto**](SeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getSeriesThumbnail**
> Uint8List getSeriesThumbnail(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    var result = api_instance.getSeriesThumbnail(seriesId);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getSeriesThumbnail: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

[**Uint8List**](Uint8List.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: image/jpeg

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getUpdatedSeries**
> PageSeriesDto getUpdatedSeries(page, size)



Return recently updated series, but not newly added ones.

### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var page = 56; // int | Zero-based page index (0..N)
var size = 56; // int | The size of the page to be returned

try { 
    var result = api_instance.getUpdatedSeries(page, size);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->getUpdatedSeries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **int**| Zero-based page index (0..N) | [optional] [default to null]
 **size** | **int**| The size of the page to be returned | [optional] [default to null]

### Return type

[**PageSeriesDto**](PageSeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **markAsRead**
> markAsRead(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.markAsRead(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->markAsRead: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **markAsUnread**
> markAsUnread(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.markAsUnread(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->markAsUnread: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refreshMetadata2**
> refreshMetadata2(seriesId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 

try { 
    api_instance.refreshMetadata2(seriesId);
} catch (e) {
    print("Exception when calling SeriesControllerApi->refreshMetadata2: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateMetadata1**
> SeriesDto updateMetadata1(seriesId, seriesMetadataUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new SeriesControllerApi();
var seriesId = 789; // int | 
var seriesMetadataUpdateDto = new SeriesMetadataUpdateDto(); // SeriesMetadataUpdateDto | Metadata fields to update. Set a field to null to unset the metadata. You can omit fields you don't want to update.

try { 
    var result = api_instance.updateMetadata1(seriesId, seriesMetadataUpdateDto);
    print(result);
} catch (e) {
    print("Exception when calling SeriesControllerApi->updateMetadata1: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **seriesId** | **int**|  | [default to null]
 **seriesMetadataUpdateDto** | [**SeriesMetadataUpdateDto**](SeriesMetadataUpdateDto.md)| Metadata fields to update. Set a field to null to unset the metadata. You can omit fields you don&#39;t want to update. | 

### Return type

[**SeriesDto**](SeriesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
